/////////////////////////////////////////////////////////////////
//                                                             //
// Tento zdrojov kd je soust distribuce balku program,  //
//     poskytovanch jako doplujc informace ke knize        //
//                                                             //
//      Java - grafick uivatelsk prosted a etina        //
//                                                             //
//     Pette si, prosm, dkladn upozornn v souboru      // 
//                       CTI_ME.TXT                            //
//        kter je nedlnou soust tto distribuce           //
//                                                             //
//                 (c) Pavel Herout, 2001                      // 
//                                                             //
/////////////////////////////////////////////////////////////////

import java.awt.*;
import java.awt.event.*;

class Platno extends Canvas {
  private String jmeno;
  private static final int VELIKOST = 40;
  private int rez = Font.PLAIN;

  public void zmenJmeno(String jm) {
    jmeno = jm;
    repaint();
  }

  public void zmenRez(boolean bold, boolean ital) {
    rez = Font.PLAIN;
    if (bold && ital)
      rez = Font.BOLD + Font.ITALIC;
    else if (bold)
      rez = Font.BOLD;
    else if (ital)
      rez = Font.ITALIC;
    repaint();
  }

  public void paint(Graphics g) {
    Dimension d = getSize();
    int druhySloupec = d.width / 2;
    int posunRadky = g.getFontMetrics().getHeight();
    int ucari = d.height - VELIKOST / 3;
    for (int i = -2;  i <= VELIKOST / 5;  i++) {
      if (i % 2 == 0)
        g.setColor(Color.gray);
      else
        g.setColor(Color.lightGray);
      g.drawLine(0, ucari - i * 5, d.width - 1, ucari - i * 5);
    }
    g.setColor(Color.black);

    Font f = new Font(jmeno, Font.PLAIN, 1);
    Font fd = f.deriveFont(rez, (float) VELIKOST);
    FontMetrics fm = g.getFontMetrics(fd);
    String s = "Height: " + fm.getHeight();
    g.drawString(s, 0, 1 * posunRadky);
    s = "Ascent: " + fm.getAscent();
    g.drawString(s, 0, 2 * posunRadky);
    s = "Descent: " + fm.getDescent();
    g.drawString(s, 0, 3 * posunRadky);
    s = "Leading: " + fm.getLeading();
    g.drawString(s, 0, 4 * posunRadky);

    String text = "luouk k";
    s = "ka znak: " + sirkaZnaku(fm, text);
    g.drawString(s, druhySloupec, 1 * posunRadky);
    s = "ka etzce: " + fm.stringWidth(text);
    g.drawString(s, druhySloupec, 2 * posunRadky);
    s = "ka fontu: " + sirkaFontu(fm);
    g.drawString(s, druhySloupec, 3 * posunRadky);
    s = "Nejir znak fontu: " + fm.getMaxAdvance();
    g.drawString(s, druhySloupec, 4 * posunRadky);

    s = fd.toString();
    int i = s.indexOf('[');
    s = s.substring(i);
    g.drawString(s, 0, 5 * posunRadky);
    g.setFont(fd);
    int x = (d.width - fm.stringWidth(text)) / 2;
    g.drawString(text, x, ucari);
  }

  int sirkaZnaku(FontMetrics fm, String s) {
    char[] z = new char[s.length()];
    for (int i = 0;  i < z.length;  i++)
      z[i] = s.charAt(i);
    return fm.charsWidth(z, 0, z.length);
  }

  int sirkaFontu(FontMetrics fm) {
    int[] p = fm.getWidths();
    int suma = 0;
    for (int i = 0;  i < p.length;  i++)
      suma += p[i];
    return suma;
  }
}

public class FyzickeFonty extends Frame {
  Choice jmenaCH;
  Checkbox boldCHB, italCHB;
  Platno pl;

  FyzickeFonty() {
    super.setTitle(getClass().getName());
    pl = new Platno();
    this.add(pl, BorderLayout.CENTER);

    GraphicsEnvironment ge =
               GraphicsEnvironment.getLocalGraphicsEnvironment();
    Font[] fonty = ge.getAllFonts();
    String[] jmena = ge.getAvailableFontFamilyNames();
    jmenaCH = new Choice();
    for (int i = 0;  i < fonty.length;  i++)
      jmenaCH.add(fonty[i].getName());
//    for (int i = 0;  i < jmena.length;  i++)
//      jmenaCH.add(jmena[i]);

    jmenaCH.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent e) {
        pl.zmenJmeno(jmenaCH.getSelectedItem());
      }
    } );

    boldCHB = new Checkbox("Bold", false);
    boldCHB.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent e) {
        pl.zmenRez(boldCHB.getState(), italCHB.getState());
      }
    } );
    italCHB = new Checkbox("Ital", false);
    italCHB.addItemListener(new ItemListener() {
      public void itemStateChanged(ItemEvent e) {
        pl.zmenRez(boldCHB.getState(), italCHB.getState());
      }
    } );

    pl.zmenJmeno(jmenaCH.getSelectedItem());

    Panel p = new Panel();
    p.add(jmenaCH);
    p.add(boldCHB);
    p.add(italCHB);
    this.add(p, BorderLayout.SOUTH);

    this.setSize(380, 230);

    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {
        System.exit(1);
      }
    });
  }

  private final static int OKRAJ = 10;
  public Insets getInsets() {
    return new Insets(OKRAJ * 3, OKRAJ, OKRAJ, OKRAJ);
  }

  public static void main(String[] args) {
    new FyzickeFonty().setVisible(true);
  }
}


